#ifndef __NGP_RTC_H
#define __NGP_RTC_H

namespace MDFN_IEN_NGP
{

MDFN_FASTCALL uint8 rtc_read8(uint32 address);

}

#endif
